@@ -2,7 +2,7 @@
  * audio_output.h : audio output interface
  *****************************************************************************
  * Copyright (C) 2002 VideoLAN
- * $Id: audio_output.h,v 1.76 2003/02/02 00:57:20 jobi Exp $
+ * $Id: audio_output.h,v 1.79 2003/02/11 11:16:04 massiot Exp $
  *
  * Authors: Christophe Massiot <massiot@via.ecp.fr>
  *
@@ -68,9 +68,6 @@ struct audio_sample_format_t
 #   define AOUT_FMT_U16_NE VLC_FOURCC('u','1','6','l')
 #endif
 
-#define AFMT_S16_NE AOUT_FMT_S16_NE
-#define AFMT_U16_NE AOUT_FMT_U16_NE
-
 #define AOUT_FMT_NON_LINEAR( p_format )                                    \
     ( ((p_format)->i_format == VLC_FOURCC('s','p','d','i'))                \
        || ((p_format)->i_format == VLC_FOURCC('a','5','2',' '))            \
@@ -114,7 +111,9 @@ typedef int32_t vlc_fixed_t;
 #define AOUT_CHAN_REARCENTER        0x10
 #define AOUT_CHAN_REARLEFT          0x20
 #define AOUT_CHAN_REARRIGHT         0x40
-#define AOUT_CHAN_LFE               0x100
+#define AOUT_CHAN_MIDDLELEFT        0x100
+#define AOUT_CHAN_MIDDLERIGHT       0x200
+#define AOUT_CHAN_LFE               0x1000
 
 /* Values available for original channels only */
 #define AOUT_CHAN_DOLBYSTEREO       0x10000
@@ -178,12 +177,18 @@ VLC_EXPORT( void, aout_DecDeleteBuffer, ( aout_instance_t *, aout_input_t *, aou
 VLC_EXPORT( int, aout_DecPlay, ( aout_instance_t *, aout_input_t *, aout_buffer_t * ) );
 
 /* From intf.c : */
-VLC_EXPORT( int, aout_VolumeGet, ( aout_instance_t *, audio_volume_t * ) );
-VLC_EXPORT( int, aout_VolumeSet, ( aout_instance_t *, audio_volume_t ) );
-VLC_EXPORT( int, aout_VolumeInfos, ( aout_instance_t *, audio_volume_t * ) );
-VLC_EXPORT( int, aout_VolumeUp, ( aout_instance_t *, int, audio_volume_t * ) );
-VLC_EXPORT( int, aout_VolumeDown, ( aout_instance_t *, int, audio_volume_t * ) );
-VLC_EXPORT( int, aout_VolumeMute, ( aout_instance_t *, audio_volume_t * ) );
+#define aout_VolumeGet(a, b) __aout_VolumeGet(VLC_OBJECT(a), b)
+VLC_EXPORT( int, __aout_VolumeGet, ( vlc_object_t *, audio_volume_t * ) );
+#define aout_VolumeSet(a, b) __aout_VolumeSet(VLC_OBJECT(a), b)
+VLC_EXPORT( int, __aout_VolumeSet, ( vlc_object_t *, audio_volume_t ) );
+#define aout_VolumeInfos(a, b) __aout_VolumeInfos(VLC_OBJECT(a), b)
+VLC_EXPORT( int, __aout_VolumeInfos, ( vlc_object_t *, audio_volume_t * ) );
+#define aout_VolumeUp(a, b, c) __aout_VolumeUp(VLC_OBJECT(a), b, c)
+VLC_EXPORT( int, __aout_VolumeUp, ( vlc_object_t *, int, audio_volume_t * ) );
+#define aout_VolumeDown(a, b, c) __aout_VolumeDown(VLC_OBJECT(a), b, c)
+VLC_EXPORT( int, __aout_VolumeDown, ( vlc_object_t *, int, audio_volume_t * ) );
+#define aout_VolumeMute(a, b) __aout_VolumeMute(VLC_OBJECT(a), b)
+VLC_EXPORT( int, __aout_VolumeMute, ( vlc_object_t *, audio_volume_t * ) );
 VLC_EXPORT( int, aout_Restart, ( aout_instance_t * p_aout ) );
 VLC_EXPORT( void, aout_FindAndRestart, ( vlc_object_t * p_this ) );
 VLC_EXPORT( int, aout_ChannelsRestart, ( vlc_object_t *, const char *, vlc_value_t, vlc_value_t, void * ) );
