@@ -2,7 +2,7 @@
  * stream_output.h : stream output module
  *****************************************************************************
  * Copyright (C) 2002 VideoLAN
- * $Id: stream_output.h,v 1.5 2003/02/16 14:10:44 fenrir Exp $
+ * $Id: stream_output.h,v 1.8 2003/02/25 17:17:43 fenrir Exp $
  *
  * Authors: Christophe Massiot <massiot@via.ecp.fr>
  *          Laurent Aimar <fenrir@via.ecp.fr>
@@ -36,6 +36,7 @@
  * i_size: size of valid data
  *
  */
+#define SOUT_BUFFER_FLAGS_HEADER    0x0001
 struct sout_buffer_t
 {
     size_t                  i_allocated_size;
@@ -50,6 +51,7 @@ struct sout_buffer_t
     mtime_t                 i_dts;
     mtime_t                 i_pts;
 
+    uint32_t                i_flags;
     int                     i_bitrate;
 
     struct sout_buffer_t    *p_next;
@@ -107,11 +109,26 @@ struct sout_access_out_t
     int                     (* pf_write )( sout_access_out_t *,
                                            sout_buffer_t * );
 };
+/*
+ * i_query parameter of pf_mux_capacity
+ */
+/* SOUT_MUX_CAP_GET_ADD_STREAM_ANY_TIME:    p_args=NULL, p_answer=&boolean */
+#define SOUT_MUX_CAP_GET_ADD_STREAM_ANY_TIME    0x01
+/* SOUT_MUX_CAP_GET_STREAMABLE:             p_args=NULL, p_answer=&boolean */
+#define SOUT_MUX_CAP_GET_STREAMABLE             0x02
+/*
+ * return error code
+ */
+#define SOUT_MUX_CAP_ERR_OK                 0x00
+#define SOUT_MUX_CAP_ERR_UNKNOWN            0x01
+#define SOUT_MUX_CAP_ERR_UNIMPLEMENTED      0x02
 
+typedef struct sout_instance_sys_t sout_instance_sys_t;
 struct sout_instance_t
 {
     VLC_COMMON_MEMBERS
 
+
     char * psz_dest;
     char * psz_access;
     char * psz_mux;
@@ -124,6 +141,8 @@ struct sout_instance_t
     module_t                *p_mux;
     void                    *p_mux_data;
     int                     i_mux_preheader;
+    int                     (* pf_mux_capacity)  ( sout_instance_t *,
+                                                   int, void *, void *);
     int                     (* pf_mux_addstream )( sout_instance_t *,
                                                    sout_input_t * );
     int                     (* pf_mux_delstream )( sout_instance_t *,
@@ -135,6 +154,8 @@ struct sout_instance_t
 
     int                     i_nb_inputs;
     sout_input_t            **pp_inputs;
+
+    sout_instance_sys_t     *p_sys;
 };
 
 
@@ -169,7 +190,7 @@ VLC_EXPORT( sout_buffer_t*, sout_BufferDuplicate,(sout_instance_t *, sout_buffer
 VLC_EXPORT( void,           sout_BufferChain,  ( sout_buffer_t **, sout_buffer_t * ) );
 
 VLC_EXPORT( sout_access_out_t *, sout_AccessOutNew, ( sout_instance_t *, char *psz_access, char *psz_name ) );
-VLC_EXPORT( void,                sout_AccessDelete, ( sout_access_out_t * ) );
-VLC_EXPORT( int,                 sout_AccessSeek,   ( sout_access_out_t *, off_t ) );
-VLC_EXPORT( int,                 sout_AccessWrite,  ( sout_access_out_t *, sout_buffer_t * ) );
+VLC_EXPORT( void,                sout_AccessOutDelete, ( sout_access_out_t * ) );
+VLC_EXPORT( int,                 sout_AccessOutSeek,   ( sout_access_out_t *, off_t ) );
+VLC_EXPORT( int,                 sout_AccessOutWrite,  ( sout_access_out_t *, sout_buffer_t * ) );
 
