@@ -3,7 +3,7 @@
  * Collection of useful common types and macros definitions
  *****************************************************************************
  * Copyright (C) 1998, 1999, 2000 VideoLAN
- * $Id: vlc_common.h,v 1.54 2003/02/16 14:10:44 fenrir Exp $
+ * $Id: vlc_common.h,v 1.57 2003/03/04 21:12:04 gbazin Exp $
  *
  * Authors: Samuel Hocevar <sam@via.ecp.fr>
  *          Vincent Seguin <seguin@via.ecp.fr>
@@ -101,6 +101,10 @@ typedef int                 ptrdiff_t;
 #   endif
 #endif
 
+#if defined( WIN32 )
+#   include <malloc.h>
+#endif
+
 #if defined( WIN32 ) || defined( UNDER_CE )
 typedef int                 ssize_t;
 #endif
@@ -612,6 +616,10 @@ typedef __int64 off_t;
 
 #   ifndef O_NONBLOCK
 #       define O_NONBLOCK 0
+#   endif
+
+#   ifndef alloca
+#       define alloca _alloca
 #   endif
 
     /* These two are not defined in mingw32 (bug?) */
@@ -657,7 +665,11 @@ VLC_EXPORT( char *, vlc_dgettext, ( const char *package, const char *msgid ) );
 #elif defined( ENABLE_NLS ) && defined( HAVE_INCLUDED_GETTEXT )
 #   include "libintl.h"
 #   undef _
+#if defined( __BORLANDC__ )
+#define _(String) vlc_dgettext (PACKAGE_TARNAME, String)
+#else
 #   define _(String) vlc_dgettext (PACKAGE, String)
+#endif
 #   define N_(String) ((char*)(String))
 #elif defined( ENABLE_NLS ) && defined( HAVE_GETTEXT )
 #   include <libintl.h>
