@@ -2,7 +2,7 @@
  * mms.c: MMS access plug-in
  *****************************************************************************
  * Copyright (C) 2001, 2002 VideoLAN
- * $Id: mms.c,v 1.18 2003/02/07 23:36:55 marcari Exp $
+ * $Id: mms.c,v 1.22 2003/03/03 14:21:08 gbazin Exp $
  *
  * Authors: Laurent Aimar <fenrir@via.ecp.fr>
  *
@@ -45,8 +45,6 @@
 
 #ifdef HAVE_UNISTD_H
 #   include <unistd.h>
-#elif defined( _MSC_VER ) && defined( _WIN32 )
-#   include <io.h>
 #endif
 
 #ifdef WIN32
@@ -70,6 +68,8 @@
 #include "buffer.h"
 #include "mms.h"
 
+#undef MMS_DEBUG
+
 /****************************************************************************
  * NOTES:
  *  MMSProtocole documentation found at http://get.to/sdp
@@ -134,20 +134,20 @@ static void mms_ParseURL( url_t *p_url, char *psz_url );
 vlc_module_begin();
     set_description( _("MMS access module") );
     set_capability( "access", 0 );
-    add_category_hint( "stream", NULL );
+    add_category_hint( "stream", NULL, VLC_TRUE );
         add_integer( "mms-caching", 4 * DEFAULT_PTS_DELAY / 1000, NULL,
-                     CACHING_TEXT, CACHING_LONGTEXT );
+                     CACHING_TEXT, CACHING_LONGTEXT, VLC_TRUE );
 
         add_bool( "mms-all", 0, NULL,
                   "force selection of all streams",
-                  "force selection of all streams" );
+                  "force selection of all streams", VLC_TRUE );
 
         add_string( "mms-stream", NULL, NULL,
                     "streams selection",
-                    "force this stream selection" );
+                    "force this stream selection", VLC_TRUE );
         add_integer( "mms-maxbitrate", 0, NULL,
                      "max bitrate",
-                     "set max bitrate for auto streams selections" );
+                     "set max bitrate for auto streams selections", VLC_FALSE );
     add_shortcut( "mms" );
     add_shortcut( "mmsu" );
     add_shortcut( "mmst" );
@@ -261,7 +261,13 @@ static int Open( vlc_object_t *p_this )
         p_input->stream.b_connected = 1;
     }
     p_input->stream.p_selected_area->i_tell = 0;
-    if( p_access->i_packet_count <= 0 )
+    /*
+     * i_flags_broadcast
+     *  yy xx ?? ??
+     *  broadcast    yy=0x02, xx= 0x00
+     *  pre-recorded yy=0x01, xx= 0x80 if video, 0x00 no video
+     */
+    if( p_access->i_packet_count <= 0 || ( p_access->i_flags_broadcast >> 24 ) == 0x02 )
     {
         p_input->stream.b_seekable = 0;
         p_input->stream.p_selected_area->i_size = 0;
@@ -492,7 +498,7 @@ static void asf_HeaderParse( mms_stream_t stream[128],
         stream[i].i_cat = MMS_STREAM_UNKNOWN;
     }
 
-//    fprintf( stderr, " ---------------------header:%d\n", i_header );
+    //fprintf( stderr, " ---------------------header:%d\n", i_header );
     var_buffer_initread( &buffer, p_header, i_header );
 
     var_buffer_getguid( &buffer, &guid );
@@ -506,35 +512,40 @@ static void asf_HeaderParse( mms_stream_t stream[128],
 
     for( ;; )
     {
-//    fprintf( stderr, " ---------------------data:%d\n", buffer.i_data );
-        if( var_buffer_readempty( &buffer ) )
-        {
-            return;
-        }
+        //fprintf( stderr, " ---------------------data:%d\n", buffer.i_data );
 
         var_buffer_getguid( &buffer, &guid );
         i_size = var_buffer_get64( &buffer );
+
+        //fprintf( stderr, "  guid=0x%8.8x-0x%4.4x-0x%4.4x-%2.2x%2.2x%2.2x%2.2x%2.2x%2.2x%2.2x%2.2x size=%lld\n",
+        //                  guid.v1,guid.v2, guid.v3,
+        //                  guid.v4[0],guid.v4[1],guid.v4[2],guid.v4[3],
+        //                  guid.v4[4],guid.v4[5],guid.v4[6],guid.v4[7],
+        //                  i_size );
+
         if( CmpGuid( &guid, &asf_object_stream_properties_guid ) )
         {
             int     i_stream_id;
             guid_t  stream_type;
-//            msg_Dbg( p_input, "found stream_properties" );
+            //msg_Dbg( p_input, "found stream_properties" );
 
             var_buffer_getguid( &buffer, &stream_type );
             var_buffer_getmemory( &buffer, NULL, 32 );
             i_stream_id = var_buffer_get8( &buffer ) & 0x7f;
 
- //           fprintf( stderr, " 1---------------------skip:%lld\n", i_size - 24 - 32 - 16 - 1 );
+            //fprintf( stderr, " 1---------------------skip:%lld\n", i_size - 24 - 32 - 16 - 1 );
             var_buffer_getmemory( &buffer, NULL, i_size - 24 - 32 - 16 - 1);
 
             if( CmpGuid( &stream_type, &asf_object_stream_type_video ) )
             {
-//                msg_Dbg( p_input, "video stream[%d] found", i_stream_id );
+                //fprintf( stderr, "\nvideo stream[%d] found\n", i_stream_id );
+                //msg_Dbg( p_input, "video stream[%d] found", i_stream_id );
                 stream[i_stream_id].i_cat = MMS_STREAM_VIDEO;
             }
             else if( CmpGuid( &stream_type, &asf_object_stream_type_audio ) )
             {
-//                msg_Dbg( p_input, "audio stream[%d] found", i_stream_id );
+                //fprintf( stderr, "\naudio stream[%d] found\n", i_stream_id );
+                //msg_Dbg( p_input, "audio stream[%d] found", i_stream_id );
                 stream[i_stream_id].i_cat = MMS_STREAM_AUDIO;
             }
             else
@@ -557,14 +568,19 @@ static void asf_HeaderParse( mms_stream_t stream[128],
                 i_count--;
                 i_size -= 6;
             }
-//            fprintf( stderr, " 2---------------------skip:%lld\n", i_size - 24);
+            //fprintf( stderr, " 2---------------------skip:%lld\n", i_size - 24);
             var_buffer_getmemory( &buffer, NULL, i_size - 24 );
         }
         else
         {
+            //fprintf( stderr, " 3---------------------skip:%lld\n", i_size - 24);
             // skip unknown guid
             var_buffer_getmemory( &buffer, NULL, i_size - 24 );
-//            fprintf( stderr, " 3---------------------skip:%lld\n", i_size - 24);
+        }
+
+        if( var_buffer_readempty( &buffer ) )
+        {
+            return;
         }
     }
 }
@@ -867,7 +883,13 @@ static int MMSOpen( input_thread_t  *p_input,
                      buffer.p_data,
                      buffer.i_data );
 
-    mms_CommandRead( p_input, 0x01, 0 );
+    if( mms_CommandRead( p_input, 0x01, 0 ) < 0 )
+    {
+        var_buffer_free( &buffer );
+        MMSClose( p_input );
+        return( -1 );
+    }
+
     i_server_version = GetDWLE( p_access->p_cmd + MMS_CMD_HEADERSIZE + 32 );
     i_tool_version = GetDWLE( p_access->p_cmd + MMS_CMD_HEADERSIZE + 36 );
     i_update_player_url = GetDWLE( p_access->p_cmd + MMS_CMD_HEADERSIZE + 40 );
@@ -1043,13 +1065,29 @@ static int MMSOpen( input_thread_t  *p_input,
         return( -1 );
     }
     /* *** now read header packet *** */
-    if( mms_HeaderMediaRead( p_input, MMS_PACKET_HEADER ) < 0 )
+    /* XXX could be split over multiples packets */
+    for( ;; )
     {
-        msg_Err( p_input, "cannot receive header" );
-        var_buffer_free( &buffer );
-        MMSClose( p_input );
-        return( -1 );
+        if( mms_HeaderMediaRead( p_input, MMS_PACKET_HEADER ) < 0 )
+        {
+            msg_Err( p_input, "cannot receive header" );
+            var_buffer_free( &buffer );
+            MMSClose( p_input );
+            return( -1 );
+        }
+        if( p_access->i_header >= p_access->i_header_size )
+        {
+            msg_Dbg( p_input,
+                     "header complete(%d)",
+                     p_access->i_header );
+            break;
+        }
+        msg_Dbg( p_input,
+                 "header incomplete (%d/%d), reading more",
+                 p_access->i_header,
+                 p_access->i_header_size );
     }
+
     /* *** parse header and get stream and their id *** */
     /* get all streams properties,
      *
@@ -1483,7 +1521,7 @@ static int  NetFillBuffer( input_thread_t *p_input )
         i_udp_read = 0;
     }
 
-#if 1
+#if MMS_DEBUG
     if( p_access->i_proto == MMS_PROTO_UDP )
     {
         msg_Dbg( p_input,
@@ -1607,6 +1645,7 @@ static int  mms_ParsePacket( input_thread_t *p_input,
     i_packet_seq_num = GetDWLE( p_data );
     i_packet_length = GetWLE( p_data + 6 );
 
+    //msg_Warn( p_input, "------->i_packet_length=%d, i_data=%d", i_packet_length, i_data );
 
     if( i_packet_length > i_data || i_packet_length <= 8)
     {
@@ -1652,9 +1691,22 @@ static int  mms_ParsePacket( input_thread_t *p_input,
 
     if( i_packet_id == p_access->i_header_packet_id_type )
     {
-        FREE( p_access->p_header );
-        p_access->p_header = p_packet;
-        p_access->i_header = i_packet_length - 8;
+        if( p_access->p_header )
+        {
+            p_access->p_header = realloc( p_access->p_header,
+                                          p_access->i_header + i_packet_length - 8 );
+            memcpy( &p_access->p_header[p_access->i_header],
+                    p_packet,
+                    i_packet_length - 8 );
+            p_access->i_header += i_packet_length - 8;
+
+            free( p_packet );
+        }
+        else
+        {
+            p_access->p_header = p_packet;
+            p_access->i_header = i_packet_length - 8;
+        }
 /*        msg_Dbg( p_input,
                  "receive header packet (%d bytes)",
                  i_packet_length - 8 ); */
