@@ -2,7 +2,7 @@
  * udp.c: raw UDP & RTP access plug-in
  *****************************************************************************
  * Copyright (C) 2001, 2002 VideoLAN
- * $Id: udp.c,v 1.10 2002/12/31 01:54:35 massiot Exp $
+ * $Id: udp.c,v 1.15 2003/03/03 14:21:08 gbazin Exp $
  *
  * Authors: Christophe Massiot <massiot@via.ecp.fr>
  *          Tristan Leteurtre <tooney@via.ecp.fr>
@@ -35,10 +35,12 @@
 #include <vlc/vlc.h>
 #include <vlc/input.h>
 
+#ifdef HAVE_SYS_TIME_H
+#    include <sys/time.h>
+#endif
+
 #ifdef HAVE_UNISTD_H
 #   include <unistd.h>
-#elif defined( _MSC_VER ) && defined( _WIN32 )
-#   include <io.h>
 #endif
 
 #ifdef WIN32
@@ -74,8 +76,8 @@ static ssize_t RTPChoose( input_thread_t *, byte_t *, size_t );
 
 vlc_module_begin();
     set_description( _("raw UDP access module") );
-    add_category_hint( N_("udp"), NULL );
-    add_integer( "udp-caching", DEFAULT_PTS_DELAY / 1000, NULL, CACHING_TEXT, CACHING_LONGTEXT );
+    add_category_hint( N_("udp"), NULL , VLC_TRUE );
+    add_integer( "udp-caching", DEFAULT_PTS_DELAY / 1000, NULL, CACHING_TEXT, CACHING_LONGTEXT, VLC_TRUE );
     set_capability( "access", 0 );
     add_shortcut( "udp" );
     add_shortcut( "udpstream" );
@@ -346,6 +348,18 @@ static ssize_t Read( input_thread_t * p_input, byte_t * p_buffer, size_t i_len )
 
         if( i_recv < 0 )
         {
+#ifdef WIN32
+            /* On win32 recv() will fail if the datagram doesn't fit inside
+             * the passed buffer, even though the buffer will be filled with
+             * the first part of the datagram. */
+            if( WSAGetLastError() == WSAEMSGSIZE )
+            {
+                msg_Err( p_input, "recv() failed. "
+                                  "Increase the mtu size (--mtu option)" );
+                i_recv = i_len;
+            }
+            else
+#endif
             msg_Err( p_input, "recv failed (%s)", strerror(errno) );
         }
 
