@@ -2,7 +2,7 @@
  * gtk_callbacks.c : Callbacks for the Gtk+ plugin.
  *****************************************************************************
  * Copyright (C) 2000, 2001 VideoLAN
- * $Id: gtk_callbacks.c,v 1.11 2003/01/31 10:54:07 sam Exp $
+ * $Id: gtk_callbacks.c,v 1.13 2003/02/09 01:56:21 massiot Exp $
  *
  * Authors: Samuel Hocevar <sam@zoy.org>
  *          Stphane Borel <stef@via.ecp.fr>
@@ -72,11 +72,15 @@ void * E_(__GtkGetIntf)( GtkWidget * widget )
 
         /* Otherwise, the parent widget has it */
         widget = gtk_menu_get_attach_widget( GTK_MENU( widget ) );
+        p_data = gtk_object_get_data( GTK_OBJECT( widget ), "p_intf" );
+        if( p_data )
+        {
+            return p_data;
+        }
     }
 
     /* We look for the top widget */
     widget = gtk_widget_get_toplevel( GTK_WIDGET( widget ) );
-
     p_data = gtk_object_get_data( GTK_OBJECT( widget ), "p_intf" );
 
     return p_data;
@@ -610,22 +614,10 @@ void GtkVolumeUp                      ( GtkMenuItem     *menuitem,
                                         gpointer         user_data )
 {
     intf_thread_t   *p_intf = GtkGetIntf( menuitem );
-    aout_instance_t *p_aout;
+    audio_volume_t  i_volume;
 
-    p_aout = vlc_object_find( p_intf, VLC_OBJECT_AOUT, FIND_ANYWHERE );
-    if( p_aout != NULL )
-    {
-        if( p_intf->p_sys->b_mute )
-        {
-            audio_volume_t i_volume;
-
-            aout_VolumeMute( p_aout, &i_volume );
-            p_intf->p_sys->b_mute = ( i_volume == 0 ) ? 1 : 0;
-
-        }
-        aout_VolumeUp( p_aout, 1, NULL );
-        vlc_object_release( (vlc_object_t *)p_aout );
-    }
+    aout_VolumeUp( p_intf, 1, &i_volume );
+    p_intf->p_sys->b_mute = ( i_volume == 0 ) ? 1 : 0;
 }
 
 
@@ -633,21 +625,10 @@ void GtkVolumeDown                    ( GtkMenuItem     *menuitem,
                                         gpointer         user_data )
 {
     intf_thread_t   *p_intf = GtkGetIntf( menuitem );
-    aout_instance_t *p_aout;
+    audio_volume_t  i_volume;
 
-    p_aout = vlc_object_find( p_intf, VLC_OBJECT_AOUT, FIND_ANYWHERE );
-    if( p_aout != NULL )
-    {
-        if( p_intf->p_sys->b_mute )
-        {
-            audio_volume_t i_volume;
-
-            aout_VolumeMute( p_aout, &i_volume );
-            p_intf->p_sys->b_mute = ( i_volume == 0 ) ? 1 : 0;
-        }
-        aout_VolumeDown( p_aout, 1, NULL );
-        vlc_object_release( (vlc_object_t *)p_aout );
-    }
+    aout_VolumeDown( p_intf, 1, &i_volume );
+    p_intf->p_sys->b_mute = ( i_volume == 0 ) ? 1 : 0;
 }
 
 
@@ -655,19 +636,10 @@ void GtkVolumeMute                    ( GtkMenuItem     *menuitem,
                                         gpointer         user_data )
 {
     intf_thread_t   *p_intf = GtkGetIntf( menuitem );
-    aout_instance_t *p_aout;
     audio_volume_t i_volume;
 
-    p_aout = vlc_object_find( p_intf, VLC_OBJECT_AOUT, FIND_ANYWHERE );
-
-    if( p_aout != NULL )
-    {
-        aout_VolumeMute( p_aout, &i_volume );
-
-        p_intf->p_sys->b_mute = ( i_volume == 0 ) ? 1 : 0;
-
-        vlc_object_release( (vlc_object_t *)p_aout );
-    }
+    aout_VolumeMute( p_intf, &i_volume );
+    p_intf->p_sys->b_mute = ( i_volume == 0 ) ? 1 : 0;
 }
 
 void
