@@ -1,8 +1,8 @@
 /*****************************************************************************
  * intf.h: MacOS X interface plugin
  *****************************************************************************
- * Copyright (C) 2002 VideoLAN
- * $Id: intf.h,v 1.28 2003/02/16 23:32:06 hartman Exp $
+ * Copyright (C) 2002-2003 VideoLAN
+ * $Id: intf.h,v 1.32 2003/03/06 12:05:05 hartman Exp $
  *
  * Authors: Jon Lech Johansen <jon-vl@nanocrew.net>
  *          Christophe Massiot <massiot@via.ecp.fr>
@@ -42,6 +42,7 @@
 - (void)initIntlSupport;
 - (NSString *)localizedString:(char *)psz;
 - (char *)delocalizeString:(NSString *)psz;
+- (NSStringEncoding)getEncoding;
 
 - (void)setIntf:(intf_thread_t *)p_intf;
 - (intf_thread_t *)getIntf;
@@ -49,6 +50,10 @@
 @end
 
 #define _NS(s) [NSApp localizedString: _(s)]
+/* Get an alternate version of the string.
+ * This string is stored as '1:string' but when displayed it only displays
+ * the translated string. the translation should be '1:translatedstring' though */
+#define _ANS(s) [[NSApp localizedString: _(s)] substringFromIndex:2]
 
 int ExecuteOnMainThread( id target, SEL sel, void * p_arg );
 
@@ -118,7 +123,6 @@ struct intf_sys_t
 
     IBOutlet id o_messages;     /* messages tv    */
     IBOutlet id o_msgs_panel;   /* messages panel */
-    IBOutlet id o_msgs_btn_ok;  /* messages btn   */
     NSMutableArray * o_msg_arr; /* messages array */
     NSLock * o_msg_lock;        /* messages lock  */
     IBOutlet id o_msgs_btn_crashlog;	/* messages open crashlog */
@@ -209,6 +213,8 @@ struct intf_sys_t
     IBOutlet id o_dmi_previous;
 }
 
+- (id)getControls;
+
 - (void)terminate;
 
 - (void)manage;
