@@ -2,7 +2,7 @@
  * vout.m: MacOS X video output plugin
  *****************************************************************************
  * Copyright (C) 2001-2003 VideoLAN
- * $Id: vout.m,v 1.34 2003/02/15 12:57:51 hartman Exp $
+ * $Id: vout.m,v 1.39 2003/03/06 14:40:43 hartman Exp $
  *
  * Authors: Colin Delacroix <colin@zoy.org>
  *          Florian G. Pflug <fgp@phlo.org>
@@ -745,7 +745,7 @@ static void QTFreePicture( vout_thread_t *p_vout, picture_t *p_pic )
 - (void)scaleWindowWithFactor: (float)factor
 {
     NSSize newsize;
-    int i_corrected_height;
+    int i_corrected_height, i_corrected_width;
     NSPoint topleftbase;
     NSPoint topleftscreen;
     
@@ -755,10 +755,22 @@ static void QTFreePicture( vout_thread_t *p_vout, picture_t *p_pic )
         topleftbase.y = [self frame].size.height;
         topleftscreen = [self convertBaseToScreen: topleftbase];
         
-        i_corrected_height = p_vout->output.i_width * VOUT_ASPECT_FACTOR /
+        if( p_vout->output.i_height * p_vout->output.i_aspect > 
+                        p_vout->output.i_width * VOUT_ASPECT_FACTOR )
+        {
+            i_corrected_width = p_vout->output.i_height * p_vout->output.i_aspect /
+                                            VOUT_ASPECT_FACTOR;
+            newsize.width = (int) ( i_corrected_width * factor );
+            newsize.height = (int) ( p_vout->render.i_height * factor );
+        }
+        else
+        {
+            i_corrected_height = p_vout->output.i_width * VOUT_ASPECT_FACTOR /
                                             p_vout->output.i_aspect;
-        newsize.width = (int) ( p_vout->render.i_width * factor );
-        newsize.height = (int) ( i_corrected_height * factor );
+            newsize.width = (int) ( p_vout->render.i_width * factor );
+            newsize.height = (int) ( i_corrected_height * factor );
+        }
+    
         [self setContentSize: newsize];
         
         [self setFrameTopLeftPoint: topleftscreen];
@@ -819,10 +831,11 @@ static void QTFreePicture( vout_thread_t *p_vout, picture_t *p_pic )
 
 - (void)updateTitle
 {
-    NSMutableString *o_title;
+    NSMutableString * o_title;
+
     intf_thread_t * p_intf = [NSApp getIntf];
     playlist_t * p_playlist = vlc_object_find( p_intf, VLC_OBJECT_PLAYLIST,
-                                               FIND_ANYWHERE );
+                                                       FIND_ANYWHERE );
     
     if( p_playlist == NULL )
     {
@@ -836,11 +849,13 @@ static void QTFreePicture( vout_thread_t *p_vout, picture_t *p_pic )
 
     vlc_object_release( p_playlist );
 
-    if (o_title)
+    if( o_title != nil )
     {
-        NSRange prefixrange = [o_title rangeOfString: @"file:"];
-        if ( prefixrange.location != NSNotFound )
-            [o_title deleteCharactersInRange: prefixrange];
+        NSRange prefix_range = [o_title rangeOfString: @"file:"];
+        if( prefix_range.location != NSNotFound )
+        {
+            [o_title deleteCharactersInRange: prefix_range];
+        }
 
         [self setTitleWithRepresentedFilename: o_title];
     }
@@ -906,28 +921,165 @@ static void QTFreePicture( vout_thread_t *p_vout, picture_t *p_pic )
     return( YES );
 }
 
+- (void)mouseDown:(NSEvent *)o_event
+{
+    vout_thread_t * p_vout;
+    id o_window = [self window];
+    p_vout = (vout_thread_t *)[o_window getVout];
+    vlc_value_t val;
+
+    switch( [o_event type] )
+    {        
+        case NSLeftMouseDown:
+        {
+            var_Get( p_vout, "mouse-button-down", &val );
+            val.i_int |= 1;
+            var_Set( p_vout, "mouse-button-down", val );
+        }
+        break;
+        
+        default:
+            [super mouseDown: o_event];
+        break;
+    }
+}
+
+- (void)otherMouseDown:(NSEvent *)o_event
+{
+    /* This is not the the wheel button. you need to poll the
+     * mouseWheel event for that. other is a third, forth or fifth button */
+    vout_thread_t * p_vout;
+    id o_window = [self window];
+    p_vout = (vout_thread_t *)[o_window getVout];
+    vlc_value_t val;
+
+    switch( [o_event type] )
+    {
+        case NSOtherMouseDown:
+        {
+            var_Get( p_vout, "mouse-button-down", &val );
+            val.i_int |= 2;
+            var_Set( p_vout, "mouse-button-down", val );
+        }
+        break;
+        
+        default:
+            [super mouseDown: o_event];
+        break;
+    }
+}
+
+- (void)rightMouseDown:(NSEvent *)o_event
+{
+    vout_thread_t * p_vout;
+    id o_window = [self window];
+    p_vout = (vout_thread_t *)[o_window getVout];
+    vlc_value_t val;
+
+    switch( [o_event type] )
+    {
+        case NSRightMouseDown:
+        {
+            var_Get( p_vout, "mouse-button-down", &val );
+            val.i_int |= 4;
+            var_Set( p_vout, "mouse-button-down", val );
+        }
+        break;
+        
+        default:
+            [super mouseDown: o_event];
+        break;
+    }
+}
+
 - (void)mouseUp:(NSEvent *)o_event
 {
     vout_thread_t * p_vout;
     id o_window = [self window];
     p_vout = (vout_thread_t *)[o_window getVout];
+    vlc_value_t val;
 
     switch( [o_event type] )
     {
         case NSLeftMouseUp:
         {
-            vlc_value_t val;
-            val.b_bool = VLC_TRUE;
-            var_Set( p_vout, "mouse-clicked", val );        
+            vlc_value_t b_val;
+            b_val.b_bool = VLC_TRUE;
+            var_Set( p_vout, "mouse-clicked", b_val );
+            
+            var_Get( p_vout, "mouse-button-down", &val );
+            val.i_int &= ~1;
+            var_Set( p_vout, "mouse-button-down", val );
         }
         break;
-
+                
         default:
             [super mouseUp: o_event];
         break;
     }
 }
 
+- (void)otherMouseUp:(NSEvent *)o_event
+{
+    vout_thread_t * p_vout;
+    id o_window = [self window];
+    p_vout = (vout_thread_t *)[o_window getVout];
+    vlc_value_t val;
+
+    switch( [o_event type] )
+    {
+        case NSOtherMouseUp:
+        {
+            var_Get( p_vout, "mouse-button-down", &val );
+            val.i_int &= ~2;
+            var_Set( p_vout, "mouse-button-down", val );
+        }
+        break;
+                
+        default:
+            [super mouseUp: o_event];
+        break;
+    }
+}
+
+- (void)rightMouseUp:(NSEvent *)o_event
+{
+    vout_thread_t * p_vout;
+    id o_window = [self window];
+    p_vout = (vout_thread_t *)[o_window getVout];
+    vlc_value_t val;
+
+    switch( [o_event type] )
+    {
+        case NSRightMouseUp:
+        {
+            var_Get( p_vout, "mouse-button-down", &val );
+            val.i_int &= ~4;
+            var_Set( p_vout, "mouse-button-down", val );
+        }
+        break;
+        
+        default:
+            [super mouseUp: o_event];
+        break;
+    }
+}
+
+- (void)mouseDragged:(NSEvent *)o_event
+{
+    [self mouseMoved:o_event];
+}
+
+- (void)otherMouseDragged:(NSEvent *)o_event
+{
+    [self mouseMoved:o_event];
+}
+
+- (void)rightMouseDragged:(NSEvent *)o_event
+{
+    [self mouseMoved:o_event];
+}
+
 - (void)mouseMoved:(NSEvent *)o_event
 {
     NSPoint ml;
