@@ -2,7 +2,7 @@
  * dummy.c
  *****************************************************************************
  * Copyright (C) 2001, 2002 VideoLAN
- * $Id: dummy.c,v 1.2 2003/02/16 14:10:44 fenrir Exp $
+ * $Id: dummy.c,v 1.6 2003/03/03 14:21:08 gbazin Exp $
  *
  * Authors: Laurent Aimar <fenrir@via.ecp.fr>
  *          Eric Petit <titer@videolan.org>
@@ -38,8 +38,6 @@
 
 #ifdef HAVE_UNISTD_H
 #   include <unistd.h>
-#elif defined( _MSC_VER ) && defined( _WIN32 ) && !defined( UNDER_CE )
-#   include <io.h>
 #endif
 
 #include "codecs.h"
@@ -50,6 +48,7 @@
 static int     Open   ( vlc_object_t * );
 static void    Close  ( vlc_object_t * );
 
+static int Capability(sout_instance_t *, int, void *, void * );
 static int AddStream( sout_instance_t *, sout_input_t * );
 static int DelStream( sout_instance_t *, sout_input_t * );
 static int Mux      ( sout_instance_t * );
@@ -73,6 +72,7 @@ static int Open( vlc_object_t *p_this )
 
     msg_Info( p_sout, "Open" );
 
+    p_sout->pf_mux_capacity  = Capability;
     p_sout->pf_mux_addstream = AddStream;
     p_sout->pf_mux_delstream = DelStream;
     p_sout->pf_mux           = Mux;
@@ -90,6 +90,17 @@ static void Close( vlc_object_t * p_this )
     msg_Info( p_sout, "Close" );
 }
 
+static int Capability( sout_instance_t *p_sout, int i_query, void *p_args, void *p_answer )
+{
+   switch( i_query )
+   {
+        case SOUT_MUX_CAP_GET_ADD_STREAM_ANY_TIME:
+            *(vlc_bool_t*)p_answer = VLC_TRUE;
+            return( SOUT_MUX_CAP_ERR_OK );
+        default:
+            return( SOUT_MUX_CAP_ERR_UNIMPLEMENTED );
+   }
+}
 
 static int AddStream( sout_instance_t *p_sout, sout_input_t *p_input )
 {
@@ -120,7 +131,7 @@ static int Mux      ( sout_instance_t *p_sout )
 
             p_data = sout_FifoGet( p_fifo );
 
-            sout_AccessWrite( p_sout->p_access, p_data );
+            sout_AccessOutWrite( p_sout->p_access, p_data );
 
             i_count--;
         }
