@@ -2,7 +2,7 @@
  * ps.c
  *****************************************************************************
  * Copyright (C) 2001, 2002 VideoLAN
- * $Id: ps.c,v 1.6 2003/02/16 14:10:44 fenrir Exp $
+ * $Id: ps.c,v 1.10 2003/03/03 14:21:08 gbazin Exp $
  *
  * Authors: Laurent Aimar <fenrir@via.ecp.fr>
  *          Eric Petit <titer@videolan.org>
@@ -39,8 +39,6 @@
 
 #ifdef HAVE_UNISTD_H
 #   include <unistd.h>
-#elif defined( _MSC_VER ) && defined( _WIN32 ) && !defined( UNDER_CE )
-#   include <io.h>
 #endif
 
 #include "codecs.h"
@@ -53,6 +51,7 @@
 static int     Open   ( vlc_object_t * );
 static void    Close  ( vlc_object_t * );
 
+static int Capability(sout_instance_t *, int, void *, void * );
 static int AddStream( sout_instance_t *, sout_input_t * );
 static int DelStream( sout_instance_t *, sout_input_t * );
 static int Mux      ( sout_instance_t * );
@@ -116,6 +115,7 @@ static int Open( vlc_object_t *p_this )
 
     p_mux = malloc( sizeof( sout_mux_t ) );
 
+    p_sout->pf_mux_capacity  = Capability;
     p_sout->pf_mux_addstream = AddStream;
     p_sout->pf_mux_delstream = DelStream;
     p_sout->pf_mux           = Mux;
@@ -148,13 +148,24 @@ static void Close( vlc_object_t * p_this )
     p_end = sout_BufferNew( p_sout, 4 );
     SetDWBE( p_end->p_buffer, 0x01b9 );
 
-    sout_AccessWrite( p_sout->p_access, p_end );
+    sout_AccessOutWrite( p_sout->p_access, p_end );
 
     free( p_mux );
 
     p_sout->p_mux_data = NULL;
 }
 
+static int Capability( sout_instance_t *p_sout, int i_query, void *p_args, void *p_answer )
+{
+   switch( i_query )
+   {
+        case SOUT_MUX_CAP_GET_ADD_STREAM_ANY_TIME:
+            *(vlc_bool_t*)p_answer = VLC_TRUE;
+            return( SOUT_MUX_CAP_ERR_OK );
+        default:
+            return( SOUT_MUX_CAP_ERR_UNIMPLEMENTED );
+   }
+}
 
 static int AddStream( sout_instance_t *p_sout, sout_input_t *p_input )
 {
@@ -247,7 +258,7 @@ static int MuxWritePackHeader( sout_instance_t *p_sout,
     bits_write( &bits, 5,  0x1f );  // FIXME reserved
     bits_write( &bits, 3,  0 );     // stuffing bytes
     p_hdr->i_size = 14;
-    sout_AccessWrite( p_sout->p_access, p_hdr );
+    sout_AccessOutWrite( p_sout->p_access, p_hdr );
 
     return( 0 );
 }
@@ -281,7 +292,7 @@ static int MuxWriteSystemHeader( sout_instance_t *p_sout )
 
     /* FIXME missing stream_id ... */
 
-    sout_AccessWrite( p_sout->p_access, p_hdr );
+    sout_AccessOutWrite( p_sout->p_access, p_hdr );
 
     return( 0 );
 }
@@ -365,7 +376,7 @@ static int Mux      ( sout_instance_t *p_sout )
 
         p_data = sout_FifoGet( p_fifo );
         E_( EStoPES )( p_sout, &p_data, p_data, p_stream->i_stream_id, 1);
-        sout_AccessWrite( p_sout->p_access, p_data );
+        sout_AccessOutWrite( p_sout->p_access, p_data );
 
         p_mux->i_pes_count++;
 
