@@ -2,7 +2,7 @@
  * libvlc.c: main libvlc source
  *****************************************************************************
  * Copyright (C) 1998-2002 VideoLAN
- * $Id: libvlc.c,v 1.64 2003/02/14 18:22:23 sam Exp $
+ * $Id: libvlc.c,v 1.70 2003/03/04 23:36:57 massiot Exp $
  *
  * Authors: Vincent Seguin <seguin@via.ecp.fr>
  *          Samuel Hocevar <sam@zoy.org>
@@ -48,7 +48,7 @@
 
 #ifdef HAVE_UNISTD_H
 #   include <unistd.h>
-#elif defined( _MSC_VER ) && defined( _WIN32 ) && !defined( UNDER_CE )
+#elif defined( WIN32 ) && !defined( UNDER_CE )
 #   include <io.h>
 #endif
 
@@ -182,6 +182,7 @@ int VLC_Create( void )
     {
         return VLC_EGENERIC;
     }
+    vlc_thread_set_priority( p_vlc, VLC_THREAD_PRIORITY_LOW );
 
     p_vlc->psz_object_name = "root";
 
@@ -808,8 +809,6 @@ int VLC_Play( int i_object )
         return VLC_ENOOBJ;
     }
 
-    vlc_thread_set_priority( p_vlc, VLC_THREAD_PRIORITY_LOW );
-
     p_playlist = vlc_object_find( p_vlc, VLC_OBJECT_PLAYLIST, FIND_CHILD );
 
     if( !p_playlist )
@@ -979,7 +978,7 @@ static void SetLanguage ( char const *psz_lang )
      && ( defined( HAVE_GETTEXT ) || defined( HAVE_INCLUDED_GETTEXT ) )
 
     char *          psz_path;
-#ifdef SYS_DARWIN
+#if defined( SYS_DARWIN ) || defined ( WIN32 )
     char            psz_tmp[1024];
 #endif
 
@@ -1003,7 +1002,7 @@ static void SetLanguage ( char const *psz_lang )
     setlocale( LC_CTYPE, psz_lang );
 
     /* Specify where to find the locales for current domain */
-#ifndef SYS_DARWIN
+#if !defined( SYS_DARWIN ) && !defined( WIN32 )
     psz_path = LOCALEDIR;
 #else
     snprintf( psz_tmp, sizeof(psz_tmp), "%s/%s", libvlc.psz_vlcpath,
@@ -1122,7 +1121,10 @@ static void Usage( vlc_t *p_this, char const *psz_module_name )
             char *psz_bra = NULL, *psz_type = NULL, *psz_ket = NULL;
             char *psz_suf = "", *psz_prefix = NULL;
             int i;
-
+            if ( p_item->b_advanced && !config_GetInt( p_this, "advanced" ))
+            {
+                continue;
+            }
             switch( p_item->i_type )
             {
             case CONFIG_HINT_CATEGORY:
@@ -1388,9 +1390,12 @@ static void ShowConsole( void )
  *****************************************************************************/
 static int ConsoleWidth( void )
 {
+    int i_width = 80;
+
+#ifndef WIN32
     char buf[20], *psz_parser;
     FILE *file;
-    int i_ret, i_width = 80;
+    int i_ret;
 
     file = popen( "stty size 2>/dev/null", "r" );
     if( file )
@@ -1412,6 +1417,7 @@ static int ConsoleWidth( void )
 
         pclose( file );
     }
+#endif
 
     return i_width;
 }
