@@ -2,7 +2,7 @@
  * beos_init.cpp: Initialization for BeOS specific features 
  *****************************************************************************
  * Copyright (C) 1999-2001 VideoLAN
- * $Id: beos_specific.cpp,v 1.18 2002/04/26 05:43:37 sam Exp $
+ * $Id: beos_specific.cpp,v 1.29 2003/01/19 03:16:24 sam Exp $
  *
  * Authors: Jean-Marc Dressler <polux@via.ecp.fr>
  *
@@ -24,13 +24,16 @@
 #include <Roster.h>
 #include <Path.h>
 #include <Alert.h>
+#include <Message.h>
+#include <Window.h>
+
 #include <stdio.h>
 #include <string.h> /* strdup() */
 #include <malloc.h>   /* free() */
 
 extern "C"
 {
-#include <videolan/vlc.h>
+#include <vlc/vlc.h>
 }
 
 /*****************************************************************************
@@ -39,20 +42,27 @@ extern "C"
 class VlcApplication : public BApplication
 {
 public:
+    vlc_object_t *p_this;
+
     VlcApplication(char* );
     ~VlcApplication();
 
     virtual void ReadyToRun();
     virtual void AboutRequested();
+    virtual void RefsReceived(BMessage* message);
+    virtual void MessageReceived(BMessage* message);
+    
+private:
+    BWindow*     fInterfaceWindow;
+    BMessage*    fRefsMessage;
 };
 
 /*****************************************************************************
  * Static vars
  *****************************************************************************/
-static vlc_thread_t app_thread;
-static vlc_mutex_t  app_lock;
-static vlc_cond_t   app_wait;
-static char        *psz_program_path;
+
+//const uint32 INTERFACE_CREATED = 'ifcr';  /* message sent from interface */
+#include "../../modules/gui/beos/MsgVals.h"
 
 extern "C"
 {
@@ -60,35 +70,25 @@ extern "C"
 /*****************************************************************************
  * Local prototypes.
  *****************************************************************************/
-static void system_AppThread( void * args );
+static void AppThread( vlc_object_t *p_appthread );
 
 /*****************************************************************************
  * system_Init: create a BApplication object and fill in program path.
  *****************************************************************************/
-void system_Init( int *pi_argc, char *ppsz_argv[], char *ppsz_env[] )
+void system_Init( vlc_t *p_this, int *pi_argc, char *ppsz_argv[] )
 {
-    /* Prepare the lock/wait before launching the BApplication thread */
-    vlc_mutex_init( &app_lock );
-    vlc_cond_init( &app_wait );
-    vlc_mutex_lock( &app_lock );
+    p_this->p_libvlc->p_appthread =
+            (vlc_object_t *)vlc_object_create( p_this, sizeof(vlc_object_t) );
 
-    /* Create the BApplication thread */
-    vlc_thread_create( &app_thread, "app thread",
-                       (vlc_thread_func_t)system_AppThread, 0 );
-
-    /* Wait for the application to be initialized */
-    vlc_cond_wait( &app_wait, &app_lock );
-    vlc_mutex_unlock( &app_lock );
-
-    /* Destroy the locks */
-    vlc_mutex_destroy( &app_lock );
-    vlc_cond_destroy( &app_wait );
+    /* Create the BApplication thread and wait for initialization */
+    vlc_thread_create( p_this->p_libvlc->p_appthread, "app thread", AppThread,
+                       VLC_THREAD_PRIORITY_LOW, VLC_TRUE );
 }
 
 /*****************************************************************************
  * system_Configure: check for system specific configuration options.
  *****************************************************************************/
-void system_Configure( void )
+void system_Configure( vlc_t * )
 {
 
 }
@@ -96,32 +96,29 @@ void system_Configure( void )
 /*****************************************************************************
  * system_End: destroy the BApplication object.
  *****************************************************************************/
-void system_End( void )
+void system_End( vlc_t *p_this )
 {
-    free( psz_program_path );
-
     /* Tell the BApplication to die */
     be_app->PostMessage( B_QUIT_REQUESTED );
-    vlc_thread_join( app_thread );
-}
 
-/*****************************************************************************
- * system_GetProgramPath: get the full path to the program.
- *****************************************************************************/
-char * system_GetProgramPath( void )
-{
-    return( psz_program_path );
+    vlc_thread_join( p_this->p_libvlc->p_appthread );
+    vlc_object_destroy( p_this->p_libvlc->p_appthread );
+
+    free( p_this->p_libvlc->psz_vlcpath );
 }
 
 /* following functions are local */
 
 /*****************************************************************************
- * system_AppThread: the BApplication thread.
+ * AppThread: the BApplication thread.
  *****************************************************************************/
-static void system_AppThread( void * args )
+static void AppThread( vlc_object_t * p_this )
 {
-    VlcApplication *BeApp = new VlcApplication("application/x-vnd.Ink-vlc");
+    VlcApplication *BeApp = new VlcApplication("application/x-vnd.videolan-vlc");
+    vlc_object_attach( p_this, p_this->p_vlc );
+    BeApp->p_this = p_this;
     BeApp->Run();
+    vlc_object_detach( p_this );
     delete BeApp;
 }
 
@@ -131,7 +128,9 @@ static void system_AppThread( void * args )
  * VlcApplication: application constructor
  *****************************************************************************/
 VlcApplication::VlcApplication( char * psz_mimetype )
-               :BApplication( psz_mimetype )
+               :BApplication( psz_mimetype ),
+                fInterfaceWindow( NULL ),
+                fRefsMessage( NULL )
 {
     /* Nothing to do, we use the default constructor */
 }
@@ -142,6 +141,7 @@ VlcApplication::VlcApplication( char * psz_mimetype )
 VlcApplication::~VlcApplication( )
 {
     /* Nothing to do, we use the default destructor */
+    delete fRefsMessage;
 }
 
 /*****************************************************************************
@@ -169,11 +169,53 @@ void VlcApplication::ReadyToRun( )
     BEntry entry( &info.ref ); 
     entry.GetPath( &path ); 
     path.GetParent( &path );
-    psz_program_path = strdup( path.Path() );
+    p_this->p_libvlc->psz_vlcpath = strdup( path.Path() );
 
     /* Tell the main thread we are finished initializing the BApplication */
-    vlc_mutex_lock( &app_lock );
-    vlc_cond_signal( &app_wait );
-    vlc_mutex_unlock( &app_lock );
+    vlc_thread_ready( p_this );
 }
 
+/*****************************************************************************
+ * RefsReceived: called when files are sent to our application
+ *               (for example when the user drops fils onto our icon)
+ *****************************************************************************/
+void VlcApplication::RefsReceived(BMessage* message)
+{
+	if (fInterfaceWindow)
+		fInterfaceWindow->PostMessage(message);
+	else {
+		delete fRefsMessage;
+		fRefsMessage = new BMessage(*message);
+	}
+}
+
+/*****************************************************************************
+ * MessageReceived: a BeOS applications main message loop
+ *                  Since VlcApplication and interface are separated
+ *                  in the vlc binary and the interface plugin,
+ *                  we use this method to "stick" them together.
+ *                  The interface will post a message to the global
+ *                  "be_app" pointer when the interface is created
+ *                  containing a pointer to the interface window.
+ *                  In this way, we can keep a B_REFS_RECEIVED message
+ *                  in store for the interface window to handle later.
+ *****************************************************************************/
+void VlcApplication::MessageReceived(BMessage* message)
+{
+	switch (message->what) {
+		case INTERFACE_CREATED: {
+			BWindow* interfaceWindow;
+			if (message->FindPointer("window", (void**)&interfaceWindow) == B_OK) {
+				fInterfaceWindow = interfaceWindow;
+				if (fRefsMessage) {
+					fInterfaceWindow->PostMessage(fRefsMessage);
+					delete fRefsMessage;
+					fRefsMessage = NULL;
+				}
+			}
+			break;
+		}
+		default:
+			BApplication::MessageReceived(message);
+	}
+}
